@@ -981,8 +981,8 @@ class UnitWindow(object):
 
 		self._selectedUnitName = QtGui.QLabel()
 		self._selectedUnitValue = QtGui.QLineEdit()
-		self._selectedUnitValue.setInputMethodHints(QtCore.Qt.ImhPreferNumbers)
 		self._selectedUnitValue.textEdited.connect(self._on_value_edited)
+		maeqt.mark_numbers_preferred(self._selectedUnitValue)
 		self._selectedUnitSymbol = QtGui.QLabel()
 
 		self._selectedUnitLayout = QtGui.QHBoxLayout()
